@@ -97,5 +97,7 @@ def ping():
 def landing(request: Request):
     """TiTiler Landing page"""
     return templates.TemplateResponse(
-        name="index.html", context={"request": request}, media_type="text/html",
+        name="index.html",
+        context={"request": request},
+        media_type="text/html",
     )
